@@ -70,7 +70,7 @@ class Exceptions:
 
 class ResourceGroupsClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html)
     """
 
@@ -86,7 +86,7 @@ class ResourceGroupsClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#can_paginate)
         """
 
@@ -94,63 +94,63 @@ class ResourceGroupsClient(BaseClient):
         self,
         *,
         Name: str,
-        Description: str = None,
-        ResourceQuery: "ResourceQueryTypeDef" = None,
-        Tags: Mapping[str, str] = None,
-        Configuration: Sequence["GroupConfigurationItemTypeDef"] = None
+        Description: str = ...,
+        ResourceQuery: "ResourceQueryTypeDef" = ...,
+        Tags: Mapping[str, str] = ...,
+        Configuration: Sequence["GroupConfigurationItemTypeDef"] = ...
     ) -> CreateGroupOutputTypeDef:
         """
         Creates a resource group with the specified name and description.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Client.create_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Client.create_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#create_group)
         """
 
-    def delete_group(self, *, GroupName: str = None, Group: str = None) -> DeleteGroupOutputTypeDef:
+    def delete_group(self, *, GroupName: str = ..., Group: str = ...) -> DeleteGroupOutputTypeDef:
         """
         Deletes the specified resource group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Client.delete_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Client.delete_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#delete_group)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#generate_presigned_url)
         """
 
-    def get_group(self, *, GroupName: str = None, Group: str = None) -> GetGroupOutputTypeDef:
+    def get_group(self, *, GroupName: str = ..., Group: str = ...) -> GetGroupOutputTypeDef:
         """
         Returns information about a specified resource group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Client.get_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Client.get_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#get_group)
         """
 
-    def get_group_configuration(self, *, Group: str = None) -> GetGroupConfigurationOutputTypeDef:
+    def get_group_configuration(self, *, Group: str = ...) -> GetGroupConfigurationOutputTypeDef:
         """
         Returns the service configuration associated with the specified resource group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Client.get_group_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Client.get_group_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#get_group_configuration)
         """
 
     def get_group_query(
-        self, *, GroupName: str = None, Group: str = None
+        self, *, GroupName: str = ..., Group: str = ...
     ) -> GetGroupQueryOutputTypeDef:
         """
         Retrieves the resource query associated with the specified resource group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Client.get_group_query)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Client.get_group_query)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#get_group_query)
         """
 
@@ -159,7 +159,7 @@ class ResourceGroupsClient(BaseClient):
         Returns a list of tags that are associated with a resource group, specified by
         an ARN.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Client.get_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Client.get_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#get_tags)
         """
 
@@ -169,62 +169,58 @@ class ResourceGroupsClient(BaseClient):
         """
         Adds the specified resources to the specified group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Client.group_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Client.group_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#group_resources)
         """
 
     def list_group_resources(
         self,
         *,
-        GroupName: str = None,
-        Group: str = None,
-        Filters: Sequence["ResourceFilterTypeDef"] = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        GroupName: str = ...,
+        Group: str = ...,
+        Filters: Sequence["ResourceFilterTypeDef"] = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> ListGroupResourcesOutputTypeDef:
         """
         Returns a list of ARNs of the resources that are members of a specified resource
         group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Client.list_group_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Client.list_group_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#list_group_resources)
         """
 
     def list_groups(
         self,
         *,
-        Filters: Sequence["GroupFilterTypeDef"] = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        Filters: Sequence["GroupFilterTypeDef"] = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> ListGroupsOutputTypeDef:
         """
         Returns a list of existing resource groups in your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Client.list_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Client.list_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#list_groups)
         """
 
     def put_group_configuration(
-        self, *, Group: str = None, Configuration: Sequence["GroupConfigurationItemTypeDef"] = None
+        self, *, Group: str = ..., Configuration: Sequence["GroupConfigurationItemTypeDef"] = ...
     ) -> Dict[str, Any]:
         """
         Attaches a service configuration to the specified group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Client.put_group_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Client.put_group_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#put_group_configuration)
         """
 
     def search_resources(
-        self,
-        *,
-        ResourceQuery: "ResourceQueryTypeDef",
-        MaxResults: int = None,
-        NextToken: str = None
+        self, *, ResourceQuery: "ResourceQueryTypeDef", MaxResults: int = ..., NextToken: str = ...
     ) -> SearchResourcesOutputTypeDef:
         """
         Returns a list of AWS resource identifiers that matches the specified query.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Client.search_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Client.search_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#search_resources)
         """
 
@@ -232,7 +228,7 @@ class ResourceGroupsClient(BaseClient):
         """
         Adds tags to a resource group with the specified ARN.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Client.tag)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Client.tag)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#tag)
         """
 
@@ -242,7 +238,7 @@ class ResourceGroupsClient(BaseClient):
         """
         Removes the specified resources from the specified group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Client.ungroup_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Client.ungroup_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#ungroup_resources)
         """
 
@@ -250,27 +246,27 @@ class ResourceGroupsClient(BaseClient):
         """
         Deletes tags from a specified resource group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Client.untag)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Client.untag)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#untag)
         """
 
     def update_group(
-        self, *, GroupName: str = None, Group: str = None, Description: str = None
+        self, *, GroupName: str = ..., Group: str = ..., Description: str = ...
     ) -> UpdateGroupOutputTypeDef:
         """
         Updates the description for an existing group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Client.update_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Client.update_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#update_group)
         """
 
     def update_group_query(
-        self, *, ResourceQuery: "ResourceQueryTypeDef", GroupName: str = None, Group: str = None
+        self, *, ResourceQuery: "ResourceQueryTypeDef", GroupName: str = ..., Group: str = ...
     ) -> UpdateGroupQueryOutputTypeDef:
         """
         Updates the resource query of a group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Client.update_group_query)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Client.update_group_query)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#update_group_query)
         """
 
@@ -279,14 +275,14 @@ class ResourceGroupsClient(BaseClient):
         self, operation_name: Literal["list_group_resources"]
     ) -> ListGroupResourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/paginators.html#listgroupresourcespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_groups"]) -> ListGroupsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/paginators.html#listgroupspaginator)
         """
 
@@ -295,6 +291,6 @@ class ResourceGroupsClient(BaseClient):
         self, operation_name: Literal["search_resources"]
     ) -> SearchResourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/paginators.html#searchresourcespaginator)
         """
